'use strict';

var jsxRuntime = require('react/jsx-runtime');
var reactQuery = require('@tanstack/react-query');
var axios = require('axios');
var react = require('react');
var ActivityCalendar = require('react-activity-calendar');

// Create a global QueryClient instance
const queryClient = new reactQuery.QueryClient();
const LeetcodecalendarComponent = ({ username, graph = "default" }) => {
    reactQuery.useQueryClient(); // Get existing QueryClient if already provided
    // Debugging log to check the prop value
    react.useEffect(() => {
        console.log("Graph prop received:", graph);
    }, [graph]);
    const { data = [], isLoading, isError, error } = reactQuery.useQuery({
        queryKey: ["leetcodeData", username, graph], // Include graph in query key
        queryFn: () => handlegetdata(username, graph),
        staleTime: 0, // Forces fresh data
        refetchOnMount: true, // Ensures re-fetch on component mount
    });
    // Function to calculate the total number of submissions
    const getTotalSubmissions = (leetdata) => {
        return leetdata.reduce((total, data) => total + data.count, 0);
    };
    if (isLoading)
        return jsxRuntime.jsx("div", { children: "Loading..." });
    if (isError)
        return jsxRuntime.jsxs("div", { children: ["Error: ", error?.message] });
    return (jsxRuntime.jsx("div", { className: "bg-[#101828] text-white p-4", children: jsxRuntime.jsxs("div", { className: "flex flex-col items-center", children: [jsxRuntime.jsx("h2", { className: "text-lg font-semibold mb-2", children: graph === "yearly" ? "Last Year's LeetCode Submissions" : "LeetCode Submissions" }), data.length > 0 ? (jsxRuntime.jsx(ActivityCalendar, { data: data, labels: {
                        months: ["Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sep", "Oct", "Nov", "Dec"],
                        weekdays: ["Sun", "Mon", "Tue", "Wed", "Thu", "Fri", "Sat"],
                        totalCount: `Total submissions: ${getTotalSubmissions(data)}`,
                        legend: {
                            less: "Few submissions",
                            more: "Many submissions",
                        },
                    }, theme: {
                        light: ["#f0f0f0", "#c4edde", "#7ac7c4", "#f73859", "#384259"],
                        dark: ["#161B22", "#0E4429", "#006D32", "#26A641", "#39D353"],
                    } })) : (jsxRuntime.jsx("p", { children: "No data available for the given username." }))] }) }));
};
// Fetch LeetCode data using axios
const handlegetdata = async (username, graph) => {
    if (!username || username === "string") {
        console.log("Invalid username or missing username");
        return [];
    }
    console.log(graph);
    try {
        const res = await axios.get(`https://leetcode-sub-endpoint.vercel.app/leetcode/${username}`);
        if (!res.data || typeof res.data !== "object") {
            console.error("Unexpected response format:", res.data);
            return [];
        }
        const submissionCalendar = res.data;
        // Convert object to array format
        const formattedData = Object.entries(submissionCalendar).map(([date, submission]) => ({
            date,
            count: submission,
            level: submission > 0 ? Math.min(submission, 4) : 0, // Set level (0 for no submission, up to 4)
        }));
        return formattedData;
    }
    catch (error) {
        console.error("Error fetching data:", error);
        return [];
    }
};
// **Wrapper Component to Auto-Provide QueryClient**
const Leetcodecalendar = (props) => {
    return (jsxRuntime.jsx(reactQuery.QueryClientProvider, { client: queryClient, children: jsxRuntime.jsx(LeetcodecalendarComponent, { ...props }) }));
};

exports.Leetcodecalendar = Leetcodecalendar;
//# sourceMappingURL=index.cjs.js.map
